@@ -22,11 +22,11 @@
 
 use strict;
 
-use FindBin;
-use JSON::PP;
+use FindBin  ();
+use JSON::PP ();
 use Path::Tiny qw( path );
 
-use HTTP::BrowserDetect;
+use HTTP::BrowserDetect ();
 
 my $json_text = path("$FindBin::Bin/useragents.json")->slurp;
 my $tests     = JSON::PP->new->ascii->decode($json_text);
